@@ -35,7 +35,7 @@ from gnomad.utils.vcf import (
     SITE_FIELDS,
     VQSR_FIELDS, make_hist_bin_edges_expr,
 )
-from gnomad.utils.vep import vep_struct_to_csq, VEP_CSQ_HEADER
+from gnomad.utils.vep import VEP_CSQ_HEADER
 from gnomad.variant_qc.pipeline import INBREEDING_COEFF_HARD_CUTOFF
 
 from joint_calling.resources import (
@@ -63,20 +63,14 @@ ALLELE_TYPE_FIELDS = remove_fields_from_constant(
     ALLELE_TYPE_FIELDS, MISSING_ALLELE_TYPE_FIELDS
 )
 
-# Remove SB (not included in VCF) and SOR (doesn't exist in v3.1) from site fields
-MISSING_SITES_FIELDS = ['SOR', 'SB']
-SITE_FIELDS = remove_fields_from_constant(SITE_FIELDS, MISSING_SITES_FIELDS)
-
-# Remove AS_VarDP from AS fields
-MISSING_AS_FIELDS = ['AS_VarDP']
-AS_FIELDS = remove_fields_from_constant(AS_FIELDS, MISSING_AS_FIELDS)
-
-# Make subset list (used in properly filling out VCF header descriptions and naming VCF info fields)
+# Make subset list (used in properly filling out VCF header descriptions 
+# and naming VCF info fields)
 SUBSET_LIST_FOR_VCF = SUBSETS.copy()
 SUBSET_LIST_FOR_VCF.append('')
 
 # Remove cohorts that have subpop frequencies stored as pop frequencies
-# Inclusion of these subsets significantly increases the size of storage in the VCFs because of the many subpops
+# Inclusion of these subsets significantly increases the size of storage 
+# in the VCFs because of the many subpops
 SUBSET_LIST_FOR_VCF = remove_fields_from_constant(
     SUBSET_LIST_FOR_VCF, COHORTS_WITH_POP_STORED_AS_SUBPOP
 )
@@ -90,9 +84,7 @@ REGION_FLAG_FIELDS = remove_fields_from_constant(
 # All missing fields to remove from vcf info dict
 MISSING_INFO_FIELDS = (
     MISSING_ALLELE_TYPE_FIELDS
-    + MISSING_AS_FIELDS
     + MISSING_REGION_FIELDS
-    + MISSING_SITES_FIELDS
     + RF_FIELDS
 )
 
@@ -181,8 +173,12 @@ def main(
 
     # Setup of parameters and Table/MatrixTable
     parameter_dict = _build_parameter_dict(ht, is_public_subset)
-
-    age_hist_data = hl.eval(ht.age_distribution)
+    
+    try:
+        age_hist_data = hl.eval(ht.age_distribution)
+    except AttributeError:
+        logger.warning('Age data not available')
+        age_hist_data = None
 
     vcf_ht = _prepare_vcf_ht(
         ht, 
@@ -218,12 +214,12 @@ def main(
 
 
 def _prepare_vcf_header_dict(
-    ht,
-    vcf_ht,
-    vcf_header_txt_path,
-    parameter_dict,
-    is_public_subset,
-    age_hist_data,
+    ht: hl.Table,
+    vcf_ht: hl.Table,
+    vcf_header_txt_path: str,
+    parameter_dict: Dict,
+    is_public_subset: bool,
+    age_hist_data: Optional[str] = None,
 ) -> Dict:
     logger.info('Making histogram bin edges...')
     bin_edges = make_hist_bin_edges_expr(
@@ -325,7 +321,7 @@ def populate_info_dict(
     in_silico_dict: Dict[str, Dict[str, str]] = IN_SILICO_ANNOTATIONS_INFO_DICT,
     label_delimiter: str = '_',
     bin_edges: Dict[str, str] = None,
-    age_hist_data: str = None,
+    age_hist_data: Optional[str] = None,
 ) -> Dict[str, Dict[str, str]]:
     """
     Call `make_info_dict` and `make_hist_dict` to populate INFO dictionary with 
@@ -423,6 +419,8 @@ def make_info_expr(
     :return: Dictionary containing Hail expressions for relevant INFO annotations.
     :rtype: Dict[str, hl.expr.Expression]
     """
+    t.describe()
+    
     vcf_info_dict = {}
     # Add site-level annotations to vcf_info_dict
     for field in SITE_FIELDS:
@@ -524,6 +522,7 @@ def unfurl_nested_annotations(
         to remove from the VCF.
     """
     freq_entries_to_remove_vcf = set()
+    
     expr_dict = {}
 
     if (full_release + subset_release + full_for_subset) != 1:
@@ -600,22 +599,27 @@ def unfurl_nested_annotations(
             expr_dict.update(combo_dict)
 
     if full_release:
-        logger.info('Unfurling age hists...')
-        age_hist_dict = {
-            'age_hist_het_bin_freq': hl.delimit(t.age_hist_het.bin_freq, delimiter='|'),
-            'age_hist_het_bin_edges': hl.delimit(
-                t.age_hist_het.bin_edges, delimiter='|'
-            ),
-            'age_hist_het_n_smaller': t.age_hist_het.n_smaller,
-            'age_hist_het_n_larger': t.age_hist_het.n_larger,
-            'age_hist_hom_bin_freq': hl.delimit(t.age_hist_hom.bin_freq, delimiter='|'),
-            'age_hist_hom_bin_edges': hl.delimit(
-                t.age_hist_hom.bin_edges, delimiter='|'
-            ),
-            'age_hist_hom_n_smaller': t.age_hist_hom.n_smaller,
-            'age_hist_hom_n_larger': t.age_hist_hom.n_larger,
-        }
-        expr_dict.update(age_hist_dict)
+        try:
+            logger.info('Unfurling age hists...')
+            age_hist_dict = {
+                'age_hist_het_bin_freq': hl.delimit(t.age_hist_het.bin_freq, delimiter='|'),
+                'age_hist_het_bin_edges': hl.delimit(
+                    t.age_hist_het.bin_edges, delimiter='|'
+                ),
+                'age_hist_het_n_smaller': t.age_hist_het.n_smaller,
+                'age_hist_het_n_larger': t.age_hist_het.n_larger,
+                'age_hist_hom_bin_freq': hl.delimit(t.age_hist_hom.bin_freq, delimiter='|'),
+                'age_hist_hom_bin_edges': hl.delimit(
+                    t.age_hist_hom.bin_edges, delimiter='|'
+                ),
+                'age_hist_hom_n_smaller': t.age_hist_hom.n_smaller,
+                'age_hist_hom_n_larger': t.age_hist_hom.n_larger,
+            }
+            expr_dict.update(age_hist_dict)
+        except AttributeError:
+            logger.warning('Age histograms not available')
+        else:
+            pass
 
     return hl.struct(**expr_dict), freq_entries_to_remove_vcf
 
@@ -712,7 +716,7 @@ def _prepare_vcf_ht(
 
     # logger.info('Reformatting VEP annotation...')
     # vep_expr = vep_struct_to_csq(ht.vep)
-
+    
     logger.info('Constructing INFO field')
     ht = ht.annotate(
         region_flag=region_flag_expr(
@@ -723,7 +727,14 @@ def _prepare_vcf_ht(
                 'segdup': hl.read_table(SEG_DUP_INTERVALS_HT)
             },
         ),
-        release_ht_info=ht.info,
+        # Making sure row-level fields from SITE_FIELDS are moved 
+        # into .release_ht_info, which is used in `make_info_expr`:
+        # vcf_info_dict[field] = t['release_ht_info'][f'{field}']
+        release_ht_info=ht.info.annotate(
+            monoallelic=ht.monoallelic,
+            transmitted_singleton=ht.transmitted_singleton,
+            InbreedingCoeff=ht.InbreedingCoeff,
+        ),
         info=info_struct,
         rsid=rsid_expr,
         # vep=vep_expr,
@@ -763,24 +774,24 @@ def _prepare_vcf_ht(
 def prepare_vcf_header_dict(
     t: Union[hl.Table, hl.MatrixTable],
     bin_edges: Dict[str, str],
-    age_hist_data: str,
     subset_list: List[str],
     pops: Dict[str, str],
     filtering_model_field: str = 'filtering_model',
     format_dict: Dict[str, Dict[str, str]] = FORMAT_DICT,
     inbreeding_coeff_cutoff: float = INBREEDING_COEFF_HARD_CUTOFF,
+    age_hist_data: Optional[str] = None,
 ) -> Dict[str, Dict[str, str]]:
     """
     Prepare VCF header dictionary.
 
     :param t: Input MatrixTable/Table
     :param bin_edges: Dictionary of variant annotation histograms and their associated bin edges.
-    :param age_hist_data: Pipe-delimited string of age histograms, from `get_age_distributions`.
     :param subset_list: List of sample subsets in dataset.
     :param pops: List of sample global population names for gnomAD genomes.
     :param filtering_model_field: String indicating the filtering model global annotation.
     :param format_dict: Dictionary describing MatrixTable entries. Used in header for VCF export.
     :param inbreeding_coeff_cutoff: InbreedingCoeff hard filter used for variants.
+    :param age_hist_data: Pipe-delimited string of age histograms, from `get_age_distributions`.
     :return: Prepared VCF header dictionary.
     """
     logger.info('Making FILTER dict for VCF...')
